<?php

/**
* PHP versions 5
*
* LICENSE: This source file is subject to version 3.0 of the PHP license
* that is available through the world-wide-web at the following URI:
* http://www.php.net/license. If you did not receive a copy of
* the PHP License and are unable to obtain it through the web, please
* send a note to license@php.net so we can mail you a copy immediately.
*
* @package    QuickTicket
* @author     Philippe Vandenberghe <info@qt-cute.org>
* @copyright  2008-2012 The PHP Group
* @version    2.5 build:20101222
*/

session_start();
require_once('bin/qti_init.php');
include(Translate('qti_adm.php'));
include(Translate('qtim_export.php'));
if ( $oVIP->role!='A' ) die(Error(13));
require_once('bin/qti_fn_sql.php');
if ( !defined('QTI_XML_CHAR') ) define('QTI_XML_CHAR','iso-8859-1');

function ToXml($str)
{
  $str = html_entity_decode($str,ENT_QUOTES);
  if ( strstr($str,'&') ) $str = QTencode($str,'-A -Q -L -R -&');
  $str = str_replace(chr(160),' ',$str); // required for xml
  $str = QTencode($str,'& L R'); // required for xml
  return $str;
}

// INITIALISE

$intTopics = 0;
$arrYears = array(
  strval(date('Y'))=>strval(date('Y')),
  strval(date('Y')-1)=>strval(date('Y')-1),
  'old'=>'&lt; '.strval(date('Y')-1)
  );

if ( !isset($_SESSION['m_export_xml']) )
{
  $_SESSION['m_export_xml'] = array(
  'title'   => 'export_'.date('Ymd').'.xml',
  'dropbbc' => 'Y');
}

$oVIP->selfurl = 'qtim_export_adm.php';
$oVIP->selfname = $L['export']['Admin'];
$oVIP->exiturl = $oVIP->selfurl;
$oVIP->exitname = $oVIP->selfname;
$strPageversion = $L['export']['Version'].' 2.5';

// --------
// SUBMITTED
// --------

if ( isset($_POST['submit']) )
{
  // read and check mandatory
  if ( isset($_POST['dropbbc']) ) { $_SESSION['m_export_xml']['dropbbc']='Y'; } else { $_SESSION['m_export_xml']['dropbbc']='N'; }
  if ( empty($_POST['title']) ) $error='Filename '.Error(1);
  if ( substr($_POST['title'],-4,4)!='.xml' ) $_POST['title'] .= '.xml';
  if ( $_POST['section']=='-' ) $error='No data found';
  if ( $_POST['year']=='-' ) $error='No data found';

  // EXPORT COUNT
  if ( empty($error) )
  {
    $strWhere = '';
    if ( $_POST['section']!='*' ) { $strWhere .= 'forum='.$_POST['section']; } else { $strWhere .= 'forum>=0'; }
    if ( $_POST['year']!='*' ) $strWhere .= ' AND '.SqlDateCondition($_POST['year'],'firstpostdate');
    $oDB->Query( 'SELECT count(*) as countid FROM '.TABTOPIC.' WHERE '.$strWhere );
    $row=$oDB->Getrow();
    if ( $row['countid']==0 ) $error='No data found';
  }

  // ------
  // EXPORT XML
  // ------

  if ( empty($error) )
  {
    $oDB2 = new cDB($qti_dbsystem,$qti_host,$qti_database,$qti_user,$qti_pwd,$qti_port,$qti_dsn);
  
    // start export
    
    if (!headers_sent())
    {
      header('Content-Type: text/xml; charset='.QTI_XML_CHAR);
      header('Content-Disposition: attachment; filename="'.$_POST['title'].'"');
    }

    echo '<?xml version="1.0" encoding="'.QTI_XML_CHAR.'"?>',N;
    echo '<quickticket version="2.5">',N;
      
    // export topic
    $oDB->Query( 'SELECT * FROM '.TABTOPIC.' WHERE '.$strWhere );
    while($row=$oDB->Getrow()) 
    {
      $oTopic = new cTopic($row);
      
      echo '<topic id="',$oTopic->id,'" type="',$oTopic->type,'" forum="',$oTopic->parentid,'">',N;
      echo '<numid>',$oTopic->numid,'</numid>',N;
      echo '<status>',$oTopic->status,'</status>',N;
      if ( !empty($oTopic->statusdate) )    echo '<statusdate>',$oTopic->statusdate,'</statusdate>',N;
      if ( !empty($oTopic->eventdate) )     echo '<eventdate>',$oTopic->eventdate,'</eventdate>',N;
      if ( !empty($oTopic->wisheddate) )    echo '<wisheddate>',$oTopic->wisheddate,'</wisheddate>',N;
      if ( !empty($oTopic->firstpostid) )   echo '<firstpostid>',$oTopic->firstpostid,'</firstpostid>',N;
      if ( !empty($oTopic->lastpostid) )    echo '<lastpostid>',$oTopic->lastpostid,'</lastpostid>',N;
      if ( !empty($oTopic->firstpostuser) ) echo '<firstpostuser>',$oTopic->firstpostuser,'</firstpostuser>',N;
      if ( !empty($oTopic->lastpostuser) )  echo '<lastpostuser>',$oTopic->lastpostuser,'</lastpostuser>',N;
      if ( !empty($oTopic->firstpostname) ) echo '<firstpostname>',$oTopic->firstpostname,'</firstpostname>',N;
      if ( !empty($oTopic->lastpostname) )  echo '<lastpostname>',$oTopic->lastpostname,'</lastpostname>',N;
      if ( !empty($oTopic->firstpostdate) ) echo '<firstpostdate>',$oTopic->firstpostdate,'</firstpostdate>',N;
      if ( !empty($oTopic->lastpostdate) )  echo '<lastpostdate>',$oTopic->lastpostdate,'</lastpostdate>',N;
      if ( !empty($oTopic->x) )             echo '<x>',$oTopic->x,'</x>',N;
      if ( !empty($oTopic->y) )             echo '<y>',$oTopic->y,'</y>',N;
      if ( !empty($oTopic->z) )             echo '<z>',$oTopic->z,'</z>',N;
      if ( !empty($oTopic->tags) )          echo '<tags>',$oTopic->tags,'</tags>',N;
      if ( !empty($oTopic->options) )       echo '<param>',$oTopic->options,'</param>',N;
      
      echo '<posts>',N;
        
        $oDB2->Query( 'SELECT * FROM '.TABPOST.' WHERE topic='.$oTopic->id );
        while($row2=$oDB2->Getrow()) 
        {
          $oPost = new cPost($row2);
          echo '<post id="',$oPost->id,'" type="',$oPost->type,'">',N;
          echo '<icon>',$oPost->icon,'</icon>',N;
          echo '<title>',ToXml($oPost->title),'</title>',N;
          echo '<userid>',$oPost->userid,'</userid>',N;
          echo '<username>',$oPost->username,'</username>',N;
          echo '<issuedate>',$oPost->issuedate,'</issuedate>',N;
          if ( !empty($oPost->modifdate) ) echo '<modifdate>',$oPost->modifdate,'</modifdate>',N;
          if ( !empty($oPost->modifuser) ) echo '<modifuser>',$oPost->modifuser,'</modifuser>',N;
          if ( !empty($oPost->modifname) ) echo '<modifname>',$oPost->modifname,'</modifname>',N;
          echo '<textmsg>',ToXml($oPost->text),'</textmsg>',N;          
          echo '</post>',N;  // doc is not exported        
        }

      echo '</posts>',N;
      echo '</topic>',N;
    }
    
    // end export

    echo '</quickticket>';
    exit;
  }

}

// --------
// HTML START
// --------

$strHeadScript = '
<script type="text/javascript">
<!--
function ValidateForm(theForm)
{
  if (theForm.title.value.length==0) { alert("'.$L['Missing'].': File"); return false; }
  return null;
}
-->
</script>
';

include('qti_adm_p_header.php');

echo '<form method="post" action="',$oVIP->selfurl,'" onsubmit="return ValidateForm(this);">
<table class="data_o" cellspacing="0">
<tr class="data_o">
<td class="colhd colhdgroup" colspan="3">',$L['export']['Content'],'</td>
</tr>
';
echo '<tr class="data_o">
<td class="colhd colhdfirst"><label for="section">',$L['Section'],'</label></td>
<td class="colct" colspan="2">
<select id="section" name="section" size="1">
<option value="*">[ ',$L['All'],' ]</option>
<option value="-" disabled="disabled">----------</option>
',QTasTag(QTarrget(GetSections('A'))),'</select>
</td>
</tr>
';
echo '<tr class="data_o">';
echo '<td class="colhd colhdfirst"><label for="year">',$L['Topics'],'</label></td>';
echo '<td class="colct"><select id="year" name="year" size="1">
<option value="*">[ ',$L['All'],' ]</option>
<option value="-" disabled="disabled">----------</option>
';
foreach($arrYears as $intKey=>$strValue)
{
echo '<option value="',$intKey,'">',$strValue,'</option>';
}
echo '</select></td>
<td class="colct"><span class="help">&nbsp;</span></td>
</tr>
';
echo '<tr class="data_o">
<td class="colhd colhdfirst"><label for="dropbbc">',$L['export']['Drop_bbc'],'</label></td>
<td class="colct" colspan="2"><input type="checkbox" id="dropbbc" name="dropbbc"',($_SESSION['m_export_xml']['dropbbc']=='Y' ? QCHE : ''),'/> <label for="dropbbc">',$L['export']['H_Drop_bbc'],'</label></td>
</tr>
';
echo '<tr class="data_o">
<td class="colhd colhdgroup" colspan="3">',$L['Destination'],'</td>
</tr>
';
echo '<tr class="data_o">
<td class="colhd colhdfirst"><label for="title">',$L['export']['Filename'],'</label></td>
<td class="colct" colspan="2"><input type="text" id="title" name="title" size="32" maxlength="32" value="',$_SESSION['m_export_xml']['title'],'" /></td>
</tr>';
echo '<tr class="data_o">
<td class="colhd colhdgroup" colspan="3" style="padding:6px; text-align:center"><input type="submit" name="submit" value="',$L['Ok'],'" /></td>
</tr>
';
echo '</table>
</form>
';

// HTML END

include('qti_adm_p_footer.php');

?>